Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1565)

Unified Diff: chrome/browser/ui/webui/options/chromeos/change_picture_options_handler.h

Issue 931993002: Make image_decoder a Leaky LazyInstance (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix a few comments Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/options/chromeos/change_picture_options_handler.h
diff --git a/chrome/browser/ui/webui/options/chromeos/change_picture_options_handler.h b/chrome/browser/ui/webui/options/chromeos/change_picture_options_handler.h
index d0282e2ab257f2338e157149aabe8416711939e4..80ca836858753575ab3c1efe14c0da7d33d0b0aa 100644
--- a/chrome/browser/ui/webui/options/chromeos/change_picture_options_handler.h
+++ b/chrome/browser/ui/webui/options/chromeos/change_picture_options_handler.h
@@ -31,7 +31,7 @@ namespace options {
class ChangePictureOptionsHandler : public ::options::OptionsPageUIHandler,
public ui::SelectFileDialog::Listener,
public content::NotificationObserver,
- public ImageDecoder::Delegate,
+ public ImageDecoder::ImageRequest,
public CameraPresenceNotifier::Observer {
public:
ChangePictureOptionsHandler();
@@ -113,10 +113,9 @@ class ChangePictureOptionsHandler : public ::options::OptionsPageUIHandler,
// Returns handle to browser window or NULL if it can't be found.
gfx::NativeWindow GetBrowserWindow() const;
- // Overriden from ImageDecoder::Delegate:
- void OnImageDecoded(const ImageDecoder* decoder,
- const SkBitmap& decoded_image) override;
- void OnDecodeImageFailed(const ImageDecoder* decoder) override;
+ // Overriden from ImageDecoder::ImageRequest:
+ void OnImageDecoded(const SkBitmap& decoded_image) override;
+ void OnDecodeImageFailed() override;
// Returns user related to current WebUI. If this user doesn't exist,
// returns active user.
@@ -139,10 +138,6 @@ class ChangePictureOptionsHandler : public ::options::OptionsPageUIHandler,
content::NotificationRegistrar registrar_;
- // Last ImageDecoder instance used to decode an image blob received by
- // HandlePhotoTaken.
- scoped_refptr<ImageDecoder> image_decoder_;
-
DISALLOW_COPY_AND_ASSIGN(ChangePictureOptionsHandler);
};

Powered by Google App Engine
This is Rietveld 408576698